@@ -10,7 +10,7 @@ from django.views.generic.base import RedirectView
 
 try:
     from django.utils.http import url_has_allowed_host_and_scheme as safe_url
-except ImportError:
+except ImportError:  # pragma: no cover
     from django.utils.http import is_safe_url as safe_url
 
 from django.views.decorators.csrf import csrf_protect
@@ -75,7 +75,7 @@ class Login(TemplateView):
         redirect_url = ''
         allowed_hosts = django_settings.ALLOWED_HOSTS
         if '*' in allowed_hosts:
-            allowed_hosts = self.request.get_host()
+            allowed_hosts = [self.request.get_host()]
         url_is_safe = safe_url(
             url=next_url,
             allowed_hosts=allowed_hosts,
@@ -99,41 +99,50 @@ class LoginVerify(TemplateView):
         email = request.GET.get('email')
         user = authenticate(request, token=token, email=email)
         if not user:
-            if settings.LOGIN_FAILED_TEMPLATE_NAME:
-                context = self.get_context_data(**kwargs)
-                # The below settings are left in for backward compatibility
-                context['ONE_TOKEN_PER_USER'] = settings.ONE_TOKEN_PER_USER
-                context['REQUIRE_SAME_BROWSER'] = settings.REQUIRE_SAME_BROWSER
-                context['REQUIRE_SAME_IP'] = settings.REQUIRE_SAME_IP
-                context['ALLOW_SUPERUSER_LOGIN'] = settings.ALLOW_SUPERUSER_LOGIN  # NOQA: E501
-                context['ALLOW_STAFF_LOGIN'] = settings.ALLOW_STAFF_LOGIN
+            if settings.LOGIN_FAILED_REDIRECT:
+                redirect_url = get_url_path(settings.LOGIN_FAILED_REDIRECT)
+                return HttpResponseRedirect(redirect_url)
 
-                try:
-                    magiclink = MagicLink.objects.get(token=token)
-                except MagicLink.DoesNotExist:
-                    error = 'A magic link with that token could not be found'
-                    context['login_error'] = error
-                    return self.render_to_response(context)
-
-                try:
-                    magiclink.validate(request, email)
-                except MagicLinkError as error:
-                    context['login_error'] = str(error)
-
-                return self.render_to_response(context)
-            else:
+            if not settings.LOGIN_FAILED_TEMPLATE_NAME:
                 raise Http404()
 
+            context = self.get_context_data(**kwargs)
+            # The below settings are left in for backward compatibility
+            context['ONE_TOKEN_PER_USER'] = settings.ONE_TOKEN_PER_USER
+            context['REQUIRE_SAME_BROWSER'] = settings.REQUIRE_SAME_BROWSER
+            context['REQUIRE_SAME_IP'] = settings.REQUIRE_SAME_IP
+            context['ALLOW_SUPERUSER_LOGIN'] = settings.ALLOW_SUPERUSER_LOGIN  # NOQA: E501
+            context['ALLOW_STAFF_LOGIN'] = settings.ALLOW_STAFF_LOGIN
+
+            try:
+                magiclink = MagicLink.objects.get(token=token)
+            except MagicLink.DoesNotExist:
+                error = 'A magic link with that token could not be found'
+                context['login_error'] = error
+                return self.render_to_response(context)
+
+            try:
+                magiclink.validate(request, email)
+            except MagicLinkError as error:
+                context['login_error'] = str(error)
+
+            return self.render_to_response(context)
+
         login(request, user)
         log.info(f'Login successful for {email}')
 
-        magiclink = MagicLink.objects.get(token=token)
-        response = HttpResponseRedirect(magiclink.redirect_url)
+        response = self.login_complete_action()
         if settings.REQUIRE_SAME_BROWSER:
+            magiclink = MagicLink.objects.get(token=token)
             cookie_name = f'magiclink{magiclink.pk}'
             response.delete_cookie(cookie_name, magiclink.cookie_value)
         return response
 
+    def login_complete_action(self) -> HttpResponse:
+        token = self.request.GET.get('token')
+        magiclink = MagicLink.objects.get(token=token)
+        return HttpResponseRedirect(magiclink.redirect_url)
+
 
 @method_decorator(csrf_protect, name='dispatch')
 class Signup(TemplateView):
